/**
 * WindowGroup.java
 */
package UTEStatsViewer;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
/**
 * Keep track of the Windows being used by a program and invoke
 * System.exit(0) when the last window has been closed, if appropriate.
 */
public class WindowGroup implements WindowListener {
   // Vector where group members are kept.
   private Vector windowVec = new Vector();

   // Whether System.exit() is to be invoked after last Window in
   // the group has been closed.
   private boolean exitWhenEmptied;

   /**
    * Return whether System.exit(0) is to invoked after the last
    * Window in the group has been closed.
    */
   public final boolean getExitWhenEmptied() {
      return exitWhenEmptied;
   }


   /**
    * Create a WindowGroup.
    * @param exitWhenEmptied whether System.exit(0) is to be invoked
    *    after the last Window in the group has been closed.
    */
   public WindowGroup(boolean exitWhenEmptied) {
      this.exitWhenEmptied = exitWhenEmptied;
   }


   /**
    * Create a WindowGroup where System.exit(0) is not invoked
    * after the last Window in the group has been closed.
    */
   public WindowGroup() {
      this(false);
   }


   /** Dispose and remove all windows from the group. */
   public void disposeAll() {
      if (exitWhenEmptied) {
         System.exit(0);
      } else {
         int size = windowVec.size();
         for (int i = 0; i < size; i++) {
            Object obj = windowVec.elementAt(i);
            if (obj instanceof Window) {
               ((Window)obj).dispose();
            }
         }
         windowVec.removeAllElements();
      }
   }



   // Implement WindowListener interface.
   public void windowActivated(WindowEvent e) {}

   /** Remove window from group when window is closed. */
   public void windowClosed(WindowEvent e) {
      windowVec.removeElement(e.getWindow());
      if ( (windowVec.size() == 0) && exitWhenEmptied) {
         System.exit(0);
      }
   }

   public void windowClosing(WindowEvent e) {}
   public void windowDeactivated(WindowEvent e) {}
   public void windowDeiconified(WindowEvent e) {}
   public void windowIconified(WindowEvent e) {}

   /** Add window to group when window is opened. */
   public void windowOpened(WindowEvent e) {
      windowVec.addElement(e.getWindow());
   }
}
